@@ -45,10 +45,29 @@
 #' x <- cdm$cohort1 |>
 #'   addDemographics()
 #'
+#' # summarise all variables with default estimates
 #' result <- summariseResult(x)
-#'
 #' result
 #'
+#' # get only counts of records and subjects
+#' result <- summariseResult(x, variables = character())
+#' result
+#'
+#' # specify variables and estimates
+#' result <- summariseResult(
+#'   table = x,
+#'   variables = c("cohort_start_date", "age"),
+#'   estimates = c("mean", "median", "density")
+#' )
+#' result
+#'
+#' # different estimates for each variable
+#' result <- summariseResult(
+#'   table = x,
+#'   variables = list(c("age", "prior_observation"), "sex"),
+#'   estimates = list(c("min", "max"), c("count", "percentage"))
+#' )
+#'
 #' }
 #'
 summariseResult <- function(table,
@@ -57,26 +76,27 @@ summariseResult <- function(table,
                             strata = list(),
                             includeOverallStrata = TRUE,
                             variables = NULL,
-                            estimates = c("min", "q25", "median", "q75", "max", "count", "percentage"),
+                            estimates = NULL,
                             counts = TRUE,
                             weights = NULL) {
   # initial checks
   omopgenerics::assertTable(x = table, class = "tbl")
-  if (length(variables) == 0 & length(estimates) == 0 & counts == FALSE) {
+  noVariables <- !is.null(variables) & length(variables) == 0
+  noEstimates <- !is.null(estimates) & length(as.character(unlist(estimates))) == 0
+  if ((noVariables | noEstimates) & counts == FALSE) {
     cli::cli_inform("No analyses were selected.")
     return(omopgenerics::emptySummarisedResult())
   }
 
-  if (is.null(variables)) {
-    variables <- colnames(table)
-    variables <- variables[!grepl("_id", variables)]
-    if (length(weights) > 0) {variables <- variables[variables != weights]}
-  }
-
   if (inherits(table, "cdm_table")) {
-    cdm_name <- omopgenerics::cdmName(omopgenerics::cdmReference(table))
+    cdm_name <- omopgenerics::cdmName(table)
   } else {
     cdm_name <- "unknown"
+    table <- omopgenerics::newCdmTable(
+      table = table,
+      src = omopgenerics::newLocalSource(),
+      name = "temp"
+    )
   }
 
   table <- table |>
@@ -96,12 +116,6 @@ summariseResult <- function(table,
       result <- omopgenerics::emptySummarisedResult()
     }
   } else {
-    if (!is.list(variables)) {
-      variables <- list(variables)
-    }
-    if (!is.list(estimates)) {
-      estimates <- list(estimates)
-    }
     if (!is.list(group)) {
       group <- list(group)
     }
@@ -110,109 +124,131 @@ summariseResult <- function(table,
     }
     checkStrata(group, table, type = "group")
     checkStrata(strata, table)
-    functions <- checkVariablesFunctions(variables, estimates, table)
+    functions <- checkVariablesFunctions(variables, estimates, table, weights)
+
+    if (!"person_id" %in% colnames(table)) {
+      functions <- functions |>
+        dplyr::filter(!.data$estimate_name %in% c("count_person", "percentage_person"))
+    }
+    if (!"subject_id" %in% colnames(table)) {
+      functions <- functions |>
+        dplyr::filter(!.data$estimate_name %in% c("count_subject", "percentage_subject"))
+    }
 
     if (!is.null(weights)) {
       omopgenerics::validateColumn(column = weights, x = table, type = "numeric")
       rlang::check_installed("Hmisc")
     }
 
-    mes <- c("i" = "The following estimates will be computed:")
-    variables <- functions$variable_name |> unique()
-    for (vark in variables) {
-      mes <- c(mes, "*" = paste0(
-        vark, ": ", paste0(functions$estimate_name[functions$variable_name == vark], collapse = ", ")
-      ))
-    }
-    cli::cli_inform(message = mes)
-
-    # only required variables
-    colOrder <- colnames(table)
-    table <- table |>
-      dplyr::select(dplyr::any_of(unique(c(
-        unlist(strata), unlist(group), functions$variable_name, "person_id",
-        "subject_id", weights
-      ))))
-
-    # collect if necessary
-    if (length(weights) == 0) {
-      if (identical(omopgenerics::sourceType(table), "sql server")) {
-        estimatesCollect <- "q|median|density"
+    if (nrow(functions) == 0) {
+      if (counts) {
+        calculate <- TRUE
       } else {
-        estimatesCollect <- "q|density"
+        calculate <- FALSE
+        cli::cli_inform(c("!" = "No estimates will be calculated, returning empty result."))
       }
     } else {
-      estimatesCollect <- "q|median|sd|mean|density"
-    }
-    collectFlag <- functions |>
-      dplyr::filter(grepl(estimatesCollect, .data$estimate_name)) |>
-      nrow() > 0
-    # collect also if dates are present
-    collectFlag <- collectFlag | any(functions$variable_type == "date")
-    if (collectFlag) {
-      cli::cli_inform(c(
-        "!" = "Table is collected to memory as not all requested estimates are
-        supported on the database side"
-      ))
-      table <- table |> dplyr::collect()
+      mes <- c("i" = "The following estimates will be calculated:")
+      variables <- functions$variable_name |> unique()
+      for (vark in variables) {
+        mes <- c(mes, "*" = paste0(
+          vark, ": ", paste0(functions$estimate_name[functions$variable_name == vark], collapse = ", ")
+        ))
+      }
+      calculate <- TRUE
+      cli::cli_inform(message = mes)
     }
 
-    # correct dates and logicals
-    dates <- functions |>
-      dplyr::filter(.data$variable_type %in% c("date", "logical")) |>
-      dplyr::distinct(.data$variable_name) |>
-      dplyr::pull()
-    table <- table |>
-      dplyr::mutate(dplyr::across(
-        .cols = dplyr::all_of(dates),
-        .fns = as.integer
-      ))
+    # stop if no estimate needs to be calculated
+    if (calculate) {
+      # only required variables
+      colOrder <- colnames(table)
+      table <- table |>
+        dplyr::select(dplyr::any_of(unique(c(
+          unlist(strata), unlist(group), functions$variable_name, "person_id",
+          "subject_id", weights
+        ))))
 
-    # correct strata and group
-    group <- correctStrata(group, includeOverallGroup)
-    strata <- correctStrata(strata, includeOverallStrata)
-
-    cli::cli_alert("Start summary of data, at {Sys.time()}")
-    nt <- length(group) * length(strata)
-    k <- 0
-    cli::cli_progress_bar(
-      total = nt,
-      format = "{cli::pb_bar}{k}/{nt} group-strata combinations @ {Sys.time()}"
-    )
-
-    personVariable <- NULL
-    if (counts) {
-      i <- "person_id" %in% colnames(table)
-      j <- "subject_id" %in% colnames(table)
-      if (i) {
-        if (j) {
-          cli::cli_warn(
-            "person_id and subject_id present in table, `person_id` used as
-            person identifier"
-          )
+      # collect if necessary
+      if (length(weights) == 0) {
+        if (identical(omopgenerics::sourceType(table), "sql server")) {
+          estimatesCollect <- "q|median|density"
+        } else {
+          estimatesCollect <- "q|density"
         }
-        personVariable <- "person_id"
-      } else if (j) {
-        personVariable <- "subject_id"
+      } else {
+        estimatesCollect <- "q|median|sd|mean|density"
+      }
+      collectFlag <- functions |>
+        dplyr::filter(grepl(estimatesCollect, .data$estimate_name)) |>
+        nrow() > 0
+      # collect also if dates are present
+      collectFlag <- collectFlag | any(functions$variable_type == "date")
+      if (collectFlag) {
+        cli::cli_inform(c(
+          "!" = "Table is collected to memory as not all requested estimates are
+        supported on the database side"
+        ))
+        table <- table |> dplyr::collect()
       }
-    }
 
-    resultk <- 1
-    result <- list()
-    for (groupk in group) {
-      for (stratak in strata) {
-        result[[resultk]] <- summariseInternal(
-          table, groupk, stratak, functions, counts, personVariable, weights
-        ) |>
-          # order variables
-          orderVariables(colOrder, unique(unlist(estimates)))
-        resultk <- resultk + 1
-        k <- k + 1
-        cli::cli_progress_update()
+      # correct dates and logicals
+      dates <- functions |>
+        dplyr::filter(.data$variable_type %in% c("date", "logical")) |>
+        dplyr::distinct(.data$variable_name) |>
+        dplyr::pull()
+      table <- table |>
+        dplyr::mutate(dplyr::across(
+          .cols = dplyr::all_of(dates),
+          .fns = as.integer
+        ))
+
+      # correct strata and group
+      group <- correctStrata(group, includeOverallGroup)
+      strata <- correctStrata(strata, includeOverallStrata)
+
+      cli::cli_alert("Start summary of data, at {Sys.time()}")
+      nt <- length(group) * length(strata)
+      k <- 0
+      cli::cli_progress_bar(
+        total = nt,
+        format = "{cli::pb_bar}{k}/{nt} group-strata combinations @ {Sys.time()}"
+      )
+
+      personVariable <- NULL
+      if (counts) {
+        if ("person_id" %in% colnames(table)) {
+          if ("subject_id" %in% colnames(table)) {
+            cli::cli_warn(
+              "person_id and subject_id present in table, `person_id` used as
+            person identifier"
+            )
+          }
+          personVariable <- "person_id"
+        } else if ("subject_id" %in% colnames(table)) {
+          personVariable <- "subject_id"
+        }
       }
+
+      resultk <- 1
+      result <- list()
+      for (groupk in group) {
+        for (stratak in strata) {
+          result[[resultk]] <- summariseInternal(
+            table, groupk, stratak, functions, counts, personVariable, weights
+          ) |>
+            # order variables
+            orderVariables(colOrder, unique(unlist(estimates)))
+          resultk <- resultk + 1
+          k <- k + 1
+          cli::cli_progress_update()
+        }
+      }
+      result <- result |> dplyr::bind_rows()
+      cli::cli_inform(c("v" = "Summary finished, at {Sys.time()}"))
+    } else {
+      result <- omopgenerics::emptySummarisedResult()
     }
-    result <- result |> dplyr::bind_rows()
-    cli::cli_inform(c("v" = "Summary finished, at {Sys.time()}"))
   }
 
   # TO REMOVE
@@ -286,20 +322,17 @@ summariseInternal <- function(table, groupk, stratak, functions, counts, personV
 
   # count subjects and records
   if (counts) {
-    result$counts <- countSubjects(table, personVariable, weights)
+    result$counts_subjects <- countSubjects(table, personVariable, weights)
   }
 
   # summariseNumeric
   result$numeric <- summariseNumeric(table, functions, weights)
 
-  # summariseBinary
-  result$binary <- summariseBinary(table, functions, weights)
-
   # summariseCategories
   result$categories <- summariseCategories(table, functions, weights)
 
-  # summariseMissings
-  result$missings <- summariseMissings(table, functions, weights)
+  # summariseCounts
+  result$counts <- summariseCounts(table, functions, weights)
 
   result <- result |>
     dplyr::bind_rows() |>
@@ -371,7 +404,8 @@ summariseNumeric <- function(table, functions, weights) {
   functions <- functions |>
     dplyr::filter(
       .data$variable_type %in% c("date", "numeric", "integer") &
-        !grepl("count|percentage", .data$estimate_name)
+        !startsWith(.data$estimate_name, "count") &
+        !startsWith(.data$estimate_name, "percentage")
     )
 
   if (nrow(functions) == 0) {
@@ -494,12 +528,14 @@ densityResult <- function(x, w) {
   } else if (length(x) == 1) {
     den <- list(x = c(x - 1, x, x + 1), y = c(0, 1, 0)) # NEEDS DISCUSSION
   } else {
+    # Limit the x values of the density estimation to the 0.005 to 0.995 percentiles of the distribution
+    qs <- stats::quantile(x, c(0.005, 0.995), na.rm = TRUE)
     # if-else to avoid warning when weights are NULL, but important to throw when non-null
     if (is.null(w)) {
-      den <- stats::density(x, n = nPoints, na.rm = TRUE)
+      den <- stats::density(x, n = nPoints, from = qs[1], to = qs[2], na.rm = TRUE)
     } else {
       w <- as.numeric(w[id])
-      den <- stats::density(x, n = nPoints, weights = w/sum(w), na.rm = TRUE)
+      den <- stats::density(x, n = nPoints, from = qs[1], to = qs[2], weights = w/sum(w), na.rm = TRUE)
     }
 
   }
@@ -518,107 +554,47 @@ densityResult <- function(x, w) {
     dplyr::arrange(.data$variable_level, .data$estimate_name)
 }
 
-summariseBinary <- function(table, functions, weights) {
-  binFuns <- functions |>
-    dplyr::filter(
-      .data$variable_type != "categorical" &
-        .data$estimate_name %in% c("count", "percentage")
-    )
-  binNum <- binFuns |>
-    dplyr::pull("variable_name") |>
-    unique()
-  if (length(weights) == 0) {
-    weights <- omopgenerics::uniqueId(exclude = colnames(table))
-    table <- table |>
-      dplyr::mutate(!!weights := 1)
-  }
-  if (length(binNum) > 0) {
-    num <- table |>
-      dplyr::summarise(dplyr::across(
-        .cols = dplyr::all_of(binNum),
-        \(x) sum(x * !!dplyr::sym(weights), na.rm = TRUE),
-        .names = "counts_{.col}"
-      )) |>
-      dplyr::collect() |>
-      dplyr::mutate(dplyr::across(
-        .cols = dplyr::all_of(paste0("counts_", binNum)),
-        .fns = as.numeric
-      ))
-    binDen <- binFuns |>
-      dplyr::filter(.data$estimate_name == "percentage") |>
-      dplyr::pull("variable_name")
-    res <- num |>
-      tidyr::pivot_longer(
-        cols = dplyr::all_of(paste0("counts_", binNum)),
-        names_to = "variable_name",
-        values_to = "estimate_value"
-      ) |>
-      dplyr::mutate(
-        "variable_name" = substr(.data$variable_name, 8, nchar(.data$variable_name)),
-        "estimate_name" = "count",
-        "estimate_type" = "integer"
-      )
-    if (length(binDen) > 0) {
-      den <- table |>
-        dplyr::summarise(dplyr::across(
-          .cols = dplyr::all_of(binDen),
-          \(x) sum(as.integer(!is.na(x)) * !!dplyr::sym(weights), na.rm = TRUE),
-          .names = "den_{.col}"
-        )) |>
-        dplyr::collect() |>
-        dplyr::mutate(dplyr::across(
-          .cols = dplyr::all_of(paste0("den_", binDen)),
-          .fns = as.numeric
-        ))
-      percentages <- num |>
-        tidyr::pivot_longer(
-          cols = dplyr::all_of(paste0("counts_", binNum)),
-          names_to = "variable_name",
-          values_to = "numerator"
-        ) |>
-        dplyr::mutate(
-          "variable_name" = substr(.data$variable_name, 8, nchar(.data$variable_name))
-        ) |>
-        dplyr::inner_join(
-          den |>
-            tidyr::pivot_longer(
-              cols = dplyr::all_of(paste0("den_", binDen)),
-              names_to = "variable_name",
-              values_to = "denominator"
-            ) |>
-            dplyr::mutate(
-              "variable_name" = substr(.data$variable_name, 5, nchar(.data$variable_name))
-            ),
-          by = c("strata_id", "variable_name")
-        ) |>
-        dplyr::mutate(
-          "estimate_value" = 100 * .data$numerator / .data$denominator,
-          "estimate_name" = "percentage",
-          "estimate_type" = "percentage"
-        ) |>
-        dplyr::select(-c("numerator", "denominator"))
-      res <- res |> dplyr::union_all(percentages)
-    }
-
-    res <- res |>
-      dplyr::mutate(
-        "estimate_value" = dplyr::if_else(
-          is.infinite(.data$estimate_value) | is.nan(.data$estimate_value),
-          NA_character_, as.character(.data$estimate_value)
-        ),
-        "variable_level" = NA_character_
-      )
-  } else {
-    res <- NULL
-  }
-
-  return(res)
-}
-
 summariseCategories <- function(table, functions, weights) {
   catFuns <- functions |>
     dplyr::filter(.data$variable_type == "categorical")
+
   result <- list()
+
+  # count_person, count_subject
+  catSubj <- catFuns |>
+    dplyr::filter(.data$estimate_name %in% c("count_subject", "count_person"))
+  if (nrow(catSubj) > 0) {
+    estimates <- c(
+      "count_subject" = "as.numeric(dplyr::n_distinct(.data$subject_id))",
+      "count_person" = "as.numeric(dplyr::n_distinct(.data$person_id))"
+    )
+    vars <- unique(catSubj$variable_name)
+    for (var in vars) {
+      est <- catSubj |>
+        dplyr::filter(.data$variable_name == .env$var) |>
+        dplyr::pull("estimate_name")
+      q <- rlang::parse_exprs(estimates[est])
+      result[[paste0(var, "_count")]] <- table |>
+        dplyr::group_by(.data$strata_id, .data[[var]]) |>
+        dplyr::summarise(!!!q, .groups = "drop") |>
+        dplyr::collect() |>
+        tidyr::pivot_longer(
+          cols = dplyr::all_of(names(q)),
+          names_to = "estimate_name",
+          values_to = "estimate_value"
+        ) |>
+        dplyr::rename("variable_level" = dplyr::all_of(var)) |>
+        dplyr::mutate(
+          "estimate_value" = sprintf("%.0f", .data$estimate_value),
+          "estimate_type" = "integer",
+          "variable_name" = .env$var
+        )
+    }
+  }
+
+  # count and percentage
+  catFuns <- catFuns |>
+    dplyr::filter(.data$estimate_name %in% c("count", "percentage"))
   catVars <- unique(catFuns$variable_name)
   if (length(weights) == 0) {
     weights <- omopgenerics::uniqueId(exclude = colnames(table))
@@ -637,6 +613,10 @@ summariseCategories <- function(table, functions, weights) {
         dplyr::group_by(.data$strata_id, .data[[catVar]]) |>
         dplyr::summarise("count" = sum(.data[[weights]], na.rm = TRUE), .groups = "drop") |>
         dplyr::collect() |>
+
+        # TO BE REMOVED https://github.com/OHDSI/MeasurementDiagnostics/issues/136
+        dplyr::filter(!is.na(.data[[catVar]])) |>
+
         dplyr::inner_join(den, by = "strata_id") |>
         dplyr::mutate(
           "percentage" = as.character(100 * .data$count / .data$denominator),
@@ -662,62 +642,108 @@ summariseCategories <- function(table, functions, weights) {
         dplyr::filter(.data$estimate_name %in% .env$est)
     }
   }
+
   return(dplyr::bind_rows(result))
 }
 
-summariseMissings <- function(table, functions, weights) {
-  result <- list()
-  if (length(weights) == 0) {
-    weights <- omopgenerics::uniqueId(exclude = colnames(table))
-    table <- table |>
-      dplyr::mutate(!!weights := 1)
-  }
+summariseCounts <- function(table, functions, weights) {
+  # estimates
+  estimates <- names(estimatesFunc) |>
+    purrr::keep(\(x) startsWith(x = x, prefix = "count"))
+  estimates <- c(estimates, gsub("^count", "percentage", estimates))
+
   # counts
-  mVars <- functions |>
-    dplyr::filter(.data$estimate_name %in% c("count_missing", "percentage_missing")) |>
-    dplyr::pull("variable_name") |>
-    unique()
-  if (length(mVars) > 0) {
-    result <- table |>
-      dplyr::summarise(
-        dplyr::across(
-          .cols = dplyr::all_of(mVars),
-          ~ sum(as.integer(is.na(.x))*.data[[weights]], na.rm = TRUE),
-          .names = "cm_{.col}"
-        ),
-        "den" = sum(.data[[weights]], na.rm = TRUE)
-      ) |>
-      dplyr::collect() |>
-      dplyr::mutate(dplyr::across(
-        .cols = dplyr::all_of(c("den", paste0("cm_", mVars))),
-        .fns = as.numeric
+  functs <- functions |>
+    dplyr::filter(
+      .data$variable_type %in% c("integer", "numeric", "date", "logical") &
+        .data$estimate_name %in% .env$estimates
+    ) |>
+    dplyr::select("variable_name", "estimate_name", "estimate_type")
+
+  # check if estimates need to be calculated
+  if (nrow(functs) > 0) {
+
+    # assign denominators
+    functs <- functs |>
+      dplyr::mutate(den = dplyr::case_when(
+        grepl("count", .data$estimate_name) ~ NA_character_,
+        length(.env$weights) == 0 & grepl("missing", .data$estimate_name) ~ "as.numeric(dplyr::n())",
+        length(.env$weights) == 0 & !grepl("missing", .data$estimate_name) ~ paste0("as.numeric(sum(dplyr::if_else(is.na(.data[['", .data$variable_name,"']]), 0, 1), na.rm = TRUE))"),
+        length(.env$weights) != 0 & grepl("missing", .data$estimate_name) ~ "as.numeric(sum(.data[[weights]], na.rm = TRUE))",
+        length(.env$weights) != 0 & !grepl("missing", .data$estimate_name) ~ paste0("as.numeric(sum(dplyr::if_else(is.na(.data[['", .data$variable_name,"']]), 0, .data[[weights]]), na.rm = TRUE))")
+      ))
+
+    # assign denominator name
+    dens <- functs |>
+      dplyr::distinct(.data$den) |>
+      dplyr::filter(!is.na(.data$den)) |>
+      dplyr::mutate(den_name = paste0("den_", dplyr::row_number()))
+    functs <- functs |>
+      dplyr::left_join(dens, by = "den")
+
+    # assign numerator
+    functs <- functs |>
+      dplyr::mutate(num = dplyr::case_when(
+        length(.env$weights) == 0 ~ estimatesFunc[gsub("percentage", "count", .data$estimate_name)],
+        length(.env$weights) != 0 ~ estimatesFuncWeights[gsub("percentage", "count", .data$estimate_name)]
       )) |>
-      tidyr::pivot_longer(
-        cols = dplyr::all_of(paste0("cm_", mVars)),
-        names_to = "variable_name",
-        values_to = "count_missing"
+      dplyr::rowwise() |>
+      dplyr::mutate(num = gsub(
+        "\\(x", paste0("\\(.data[['", .data$variable_name, "']]"), .data$num
+      )) |>
+      dplyr::ungroup() |>
+      dplyr::mutate(num = paste0("as.numeric(", .data$num, ")"))
+
+    # assign numerator name
+    nums <- functs |>
+      dplyr::distinct(.data$num) |>
+      dplyr::mutate(num_name = paste0("num_", dplyr::row_number()))
+    functs <- functs |>
+      dplyr::left_join(nums, by = "num")
+
+    # make calculations
+    estimates <- functs |>
+      dplyr::select("value" = "num", "name" = "num_name") |>
+      dplyr::union_all(
+        functs |>
+          dplyr::select("value" = "den", "name" = "den_name")
       ) |>
-      dplyr::mutate("percentage_missing" = 100 * .data$count_missing / .data$den) |>
-      dplyr::select(-"den") |>
-      tidyr::pivot_longer(
-        cols = c("count_missing", "percentage_missing"),
-        names_to = "estimate_name",
-        values_to = "estimate_value"
+      dplyr::distinct() |>
+      dplyr::filter(!is.na(.data$value))
+    q <- estimates$value |>
+      rlang::parse_exprs() |>
+      rlang::set_names(nm = estimates$name)
+    est <- table |>
+      dplyr::summarise(!!!q) |>
+      dplyr::collect() |>
+      tidyr::pivot_longer(cols = dplyr::all_of(names(q)))
+
+    # add numerators and denominator back to functs
+    functs <- functs |>
+      dplyr::select(!c("den", "num")) |>
+      dplyr::left_join(
+        est |>
+          dplyr::select("num" = "value", "num_name" = "name", "strata_id"),
+        by = "num_name"
       ) |>
+      dplyr::left_join(
+        est |>
+          dplyr::select("den" = "value", "den_name" = "name", "strata_id"),
+        by = c("den_name", "strata_id")
+      )
+
+    # format results
+    result <- functs |>
       dplyr::mutate(
-        "variable_name" = substr(.data$variable_name, 4, nchar(.data$variable_name)),
-        "variable_level" = NA_character_,
-        "estimate_value" = dplyr::if_else(
-          is.infinite(.data$estimate_value) | is.nan(.data$estimate_value),
-          NA_character_, as.character(.data$estimate_value)
+        variable_level = NA_character_,
+        estimate_value = dplyr::case_when(
+          grepl("count", .data$estimate_name) & is.null(weights) ~ sprintf("%.0f", .data$num),
+          grepl("count", .data$estimate_name) & !is.null(weights) ~ sprintf("%.3f", .data$num),
+          is.na(.data$den) | .data$den == 0 ~ NA_character_,
+          .default = as.character(100 * .data$num / .data$den)
         )
       ) |>
-      dplyr::inner_join(
-        functions |>
-          dplyr::filter(.data$estimate_name %in% c("count_missing", "percentage_missing")) |>
-          dplyr::select("variable_name", "estimate_name", "estimate_type"),
-        by = c("variable_name", "estimate_name")
-      )
+      dplyr::select(!c("num", "num_name", "den", "den_name"))
   } else {
     result <- NULL
   }
